import cPickle

frame_data = cPickle.loads("""(lp1
(lp2
I1
aI1
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI1
aI1
aI1
aI1
aI1
aI1
aa(lp3
I1
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI1
aa(lp4
I1
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI1
aI1
aI1
aI0
aI1
aa(lp5
I1
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI0
aI0
aI1
aI0
aI1
aI1
aI1
aI0
aI1
aa(lp6
I1
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI1
aI1
aI1
aI0
aI1
aa(lp7
I1
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI1
aa(lp8
I1
aI1
aI1
aI1
aI1
aI1
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI1
aI1
aI1
aI1
aI1
aI1
aI1
aa(lp9
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp10
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp11
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp12
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp13
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp14
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp15
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp16
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp17
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp18
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp19
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp20
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp21
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp22
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp23
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp24
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp25
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp26
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp27
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp28
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp29
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp30
I0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp31
I0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp32
I0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp33
I0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp34
I0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp35
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp36
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp37
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp38
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp39
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp40
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp41
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp42
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp43
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp44
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp45
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp46
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp47
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp48
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp49
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp50
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp51
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp52
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp53
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp54
I0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp55
I0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp56
I0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp57
I0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp58
I0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp59
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp60
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp61
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp62
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp63
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp64
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp65
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp66
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp67
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp68
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp69
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp70
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp71
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp72
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp73
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp74
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp75
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp76
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp77
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp78
I0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp79
I0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp80
I0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp81
I0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp82
I0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp83
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp84
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp85
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp86
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp87
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp88
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp89
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp90
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp91
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp92
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp93
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp94
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp95
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp96
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp97
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp98
I0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp99
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp100
I0
aI1
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp101
I0
aI0
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp102
I1
aI1
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp103
I0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp104
I1
aI1
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp105
I1
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aa(lp106
I1
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aa(lp107
I1
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp108
I1
aI0
aI1
aI1
aI1
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp109
I1
aI0
aI0
aI0
aI0
aI0
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp110
I1
aI1
aI1
aI1
aI1
aI1
aI1
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aI0
aa(lp111
a.""")
